Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CronjobLister ¶
type CronjobLister interface {
// List lists all Cronjobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Cronjob, err error)
// Cronjobs returns an object that can list and get Cronjobs.
Cronjobs(namespace string) CronjobNamespaceLister
CronjobListerExpansion
}
CronjobLister helps list Cronjobs. All objects returned here must be treated as read-only.
func NewCronjobLister ¶
func NewCronjobLister(indexer cache.Indexer) CronjobLister
NewCronjobLister returns a new CronjobLister.
type CronjobListerExpansion ¶
type CronjobListerExpansion interface{}
CronjobListerExpansion allows custom methods to be added to CronjobLister.
type CronjobNamespaceLister ¶
type CronjobNamespaceLister interface {
// List lists all Cronjobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Cronjob, err error)
// Get retrieves the Cronjob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Cronjob, error)
CronjobNamespaceListerExpansion
}
CronjobNamespaceLister helps list and get Cronjobs. All objects returned here must be treated as read-only.
type CronjobNamespaceListerExpansion ¶
type CronjobNamespaceListerExpansion interface{}
CronjobNamespaceListerExpansion allows custom methods to be added to CronjobNamespaceLister.
Click to show internal directories.
Click to hide internal directories.